      PROGRAM EX1004
C
C     This program calculates the viscosity and thermal conductivity of
C     a pure nonpolar gas at temperature T (K) & high pressure P (Pa)
C     in a reduced density range 0.1 to 2.0.
C     Calculations are based on the following methods:
C     Viscosity
C     - Dilute gas  : Reduced collision integral (Neufeld)
C     - Excess term : Thodos expressions
C     Thermal Conductivity
C     - Dilute gas  : Modified Eucken correlation
C     - Excess term : Thodos expressions
C     Density required is calculated by routine PR (Peng& Robinson EoS).
C     Data required are: potential parameters e/k (K) sigma (nm),
C     EK,SIG, molecular weight WM, critical temperature TC (K), pressure
C     PC (Pa) and density DC (MOL/M3), acentric factor OMEG, and the
C     perfect-gas heat capacity coefficients, Y1,Y2,Y3,Y4.
C
      DATA EK,SIG,WM,R/215.7,0.4443,30.0694,8.3145/
      DATA Y1,Y2,Y3,Y4/5.409,0.1781,-6.938E-5,8.713E-9/
      DATA TC,PC,DC,OMEG/305.33,4.871E+6,6743.,0.099/
      DATA T,P/350.0,10.E+6/
C
C     Dilute Gas Properties, VIS & TCC
C
      TS=T/EK
      CP=Y1+Y2*T+Y3*T**2+Y4*T**3
      OMEGA=1.16145*(TS**(-0.14874))+0.52487*(EXP(-0.7732*TS))+2.16178*
     &(EXP(-2.43787*TS))-6.435E-4*(TS**0.14874)*SIN(18.0323*(TS**
     &(-0.7683))-7.2371)
      VIS=26.69E-9*((WM*T)**0.5)/(SIG*SIG*OMEGA)
      TCC=(VIS*(CP-R)/(WM/1000.))*(1.32+1.77/((CP/R)-1))
      CALL PR(T,P,2,1,1.,TC,PC,OMEG,Y1,Y2,Y3,Y4,D,H,S,FUG)
      DDC=D/DC
C
C     Excess Viscosity, DVIS
C
      XVI=((1000./WM)**(.5))*(TC**(1./6.))/(PC**(2./3.))
      DVIS=1.023+0.22364*DDC+0.58533*DDC*DDC-0.40758*(DDC**3)+0.093324*
     &(DDC**4)
      DVIS=(1.455E-9/XVI)*((DVIS**4)-1.)
      IF (P.LT.0.11E+6) DVIS=0.0
C
C     Excess Thermal Conductivity, DTCC
C
      XTC=((WM/1000.)**(.5))*(TC**(1./6.))/(PC**(2./3.))
      ZC=PC/(R*TC*DC)
      IF (DDC.LE.0.5) DTCC=(1./(XTC*(ZC**5)))*9.81E-10*(EXP(0.535*DDC)
     &-1.0)
      IF (DDC.GT.0.5.AND.DDC.LE.2.0) DTCC=(1./(XTC*(ZC**5)))*9.17E-10*
     &(EXP(0.67*DDC)-1.069)
      IF (P.LT.0.11E+6) DTCC=0.0
      WRITE(*,1000) DDC
 1000 FORMAT(1X,'@ REDUCED DENSITY : ',F6.2,/)
      WRITE(*,1100) TCC*1.E+3,VIS*1.E+6,DTCC*1.E+3,DVIS*1.E+6,
     &(TCC+DTCC)*1.E+3,(VIS+DVIS)*1.E+6
 1100 FORMAT(27X,'THERMAL CONDUCTIVITY   VISCOSITY',
     &/34X,'(mW/M/K)         (uPA.S)',
     &/3X,'DILUTE-GAS PROPERTY : ',2(10X,F6.2),
     &/3X,'EXCESS     PROPERTY : ',2(10X,F6.2),
     &/3X,'     TOTAL PROPERTY : ',2(10X,F6.2))
      END


      SUBROUTINE PR
     &(T,P,IP,IS,X,TC,PC,OMEG,Y1,Y2,Y3,Y4,D,H,S,FUG)
C
C     The subroutine calculates the following thermodynamic properties
C     of mixtures, as a function of temperature, T in [K], and pressure,
C     P in [PA]:
C          1) Density                           (D)  in [MOL/M3]
C          2) Enthalpy                          (H)  in [J/MOL]
C          3) Entropy                           (S)  in [J/MOL/K]
C          4) Partial Fugacity Coefficient    (FUG)  in [-]
C     based on the Peng & Robinson EoS, shown in Table 6.6
C
C     - Enthalpy and Entropy are arbitrary assumed to be equal to zero
C       at 273.15 K and 0.1013 MPA.
C     - Perfect-gas properties are calculated from perfect-gas Heat
C       Capacities as: CP=W1+W2*T+W3*(T**2)+W4*(T**3) in [J/MOL/K]
C       where W1=Sum(Xi*Y1i) etc.
C     - Two Switches are required from the subroutine:
C       IP = Phase specification switch (Liquid=1, Vapour=2)
C       IS = Number of components in mixture (Pure fluid=1)
C     - Other data required for each component (I) are:
C       MoleFraction X (-), Critical Temperature, TC in [K], Critical
C       Pressure in [PA], and Acentric factor, OMEG.
C
      DIMENSION X(IS),TC(IS),PC(IS),OMEG(IS),Y1(IS),Y2(IS),Y3(IS),Y4(IS)
      DIMENSION FUG(IS)
      DIMENSION A(10),B(10),FM(10),ALP(10),AS(10)
      DATA R,T0,P0/8.314,273.15,0.101325E+6/
C
C     Parameters calculation AT,BT,CT,DT &  AST,ALP
C
      BT=0.
      DO 100 I=1,IS
      AS(I)=0.45724*R*R*TC(I)*TC(I)/PC(I)
      FM(I)=0.37464+1.54226*OMEG(I)-0.26992*(OMEG(I)**2)
      ALP(I)=(1.+FM(I)*(1.-(T/TC(I))**.5))**2
      A(I)=0.45724*ALP(I)*(P/PC(I))/((T/TC(I))**2)
      B(I)=0.0778*(P/PC(I))/(T/TC(I))
  100 BT=BT+X(I)*B(I)
      AAT=0.
      AT=0.
      DT=0.
      DO 200 I=1,IS
      DO 200 J=1,IS
      AAT=AAT+X(I)*X(J)*((AS(I)*AS(J)*ALP(I)*ALP(J))**.5)
      AT=AT+X(I)*X(J)*((A(I)*A(J))**.5)
  200 DT=DT+X(I)*X(J)*FM(J)*((AS(I)*ALP(I)*AS(J)*(T/TC(J)))**.5)
C
C     Density Calculation
C
      IF (IP.EQ.1) Z=0.01
      IF (IP.EQ.2) Z=0.8
  300 F=(Z**3)-(1.-BT)*Z*Z+(AT-3.*(BT**2)-2.*BT)*Z-(AT*BT-BT*BT-BT**3)
      F1=(3.*Z*Z)-(2.*Z*(1.-BT))+(AT-3.*(BT**2)-2.*BT)
      H=F/F1
      Z=Z-H
      IF (ABS(H/Z).LE.0.0001) GOTO 400
      GOTO 300
  400 D=P/(Z*R*T)
C
C     Perfect-gas Enthalpy & Entropy
C
      W1=0.
      W2=0.
      W3=0.
      W4=0.
      DO 500 I=1,IS
      W1=W1+X(I)*Y1(I)
      W2=W2+X(I)*Y2(I)
      W3=W3+X(I)*Y3(I)
  500 W4=W4+X(I)*Y4(I)
      PGH=W1*(T-T0)+W2*((T**2)-(T0**2))/2.+W3*((T**3)-(T0**3))/3.
     &+W4*((T**4)-(T0**4))/4.
      PGS=W1*LOG(T/T0)+W2*(T-T0)+W3*((T**2)-(T0**2))/2.
     &+W4*((T**3)-(T0**3))/3.-R*LOG(P/P0)
C
C     Enthalpy & Entropy
C
      DH=1.-Z+(AT/(2.828*BT))*(1.+DT/AAT)*LOG((Z+2.414*BT)/(Z-0.414*BT))
      H=(PGH-R*T*DH)
      DS=LOG(Z-BT)-(BT*DT/(2.828*AT*AAT))*LOG((Z+2.414*BT)/
     &(Z-0.414*BT))
      S=PGS+(R*DS)
C
C     Partial Fugacities
C
      DO 700 I=1,IS
      XAAT=0.
      DO 800 J=1,IS
  800 XAAT=XAAT+X(J)* ((AS(I)*AS(J)*ALP(I)*ALP(J))**.5)
      FILN=(B(I)*(Z-1.)/BT)-LOG(Z-BT)+ (AT/(2.828*BT))*((B(I)/BT)-
     &(2.*XAAT/AAT))*LOG((Z+2.414*BT)/(Z-0.414*BT))
  700 FUG(I)=EXP(FILN)
      RETURN
      END

